"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// backend/FlowConfig.ts
var FlowConfig_exports = {};
__export(FlowConfig_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(FlowConfig_exports);
var import_client_dynamodb = require("@aws-sdk/client-dynamodb");
var import_lib_dynamodb = require("@aws-sdk/lib-dynamodb");

// backend/shared/logger.ts
var import_logger = require("@aws-lambda-powertools/logger");
var logger = new import_logger.Logger();
var logEvent = /* @__PURE__ */ __name((event, context) => {
  if (context) {
    logger.addContext(context);
  }
  if (event) {
    logger.logEventIfEnabled(event);
  }
  const ContactData = event?.Details?.ContactData;
  if (ContactData) {
    const { InstanceARN, ContactId } = ContactData;
    logger.appendKeys({
      connectInstanceId: InstanceARN?.split("/").pop(),
      connectContactId: ContactId
    });
  }
}, "logEvent");

// backend/shared/respond.ts
var respond = /* @__PURE__ */ __name((statusCode, body) => ({
  statusCode,
  body
}), "respond");
var respondObject = /* @__PURE__ */ __name((statusCode, obj) => respond(statusCode, JSON.stringify(obj)), "respondObject");
var respondMessage = /* @__PURE__ */ __name((statusCode, message) => respondObject(statusCode, { message }), "respondMessage");
var respondError = /* @__PURE__ */ __name((error) => {
  logger.error("Unhandled Server Error", error);
  return respondMessage(500, error.message);
}, "respondError");

// backend/shared/snsClient.ts
var import_client_sns = require("@aws-sdk/client-sns");

// backend/shared/getVar.ts
function getVar(name, defaultValue) {
  const val = process.env[name] || defaultValue;
  if (!val) {
    throw new Error(`Environment variable "${name}" is not defined`);
  }
  return val;
}
__name(getVar, "getVar");

// backend/shared/snsClient.ts
var client = new import_client_sns.SNSClient();
var ALERT_TOPIC_ARN = getVar("ALERT_TOPIC_ARN");
var sendError = /* @__PURE__ */ __name(async (subject, error) => {
  try {
    await client.send(
      new import_client_sns.PublishCommand({
        TopicArn: ALERT_TOPIC_ARN,
        Subject: subject,
        Message: typeof error === "string" ? error : error.message
      })
    );
  } catch (error2) {
    logger.error("Error sending message to SNS", {
      error: error2,
      sns: { subject, message: error2 }
    });
  }
}, "sendError");

// backend/shared/transformFlowConfig.ts
function transformFlowConfig(config, options) {
  const { language, channel } = options;
  logger.debug("Transforming flow config", {
    configId: config.id,
    language,
    channel
  });
  const variables = config.variables || {};
  const prompts = {};
  const rawPrompts = config.prompts || {};
  for (const [promptName, promptData] of Object.entries(rawPrompts)) {
    if (language in promptData) {
      const langData = promptData[language];
      if (channel === "chat" && langData.chat) {
        prompts[promptName] = langData.chat;
      } else if (langData.voice) {
        if (channel === "chat") {
          prompts[promptName] = stripSSML(langData.voice);
        } else {
          prompts[promptName] = langData.voice;
        }
      }
    } else {
      logger.warn(`Language ${language} not found for prompt ${promptName}`, {
        configId: config.id,
        promptName,
        availableLanguages: Object.keys(promptData)
      });
    }
  }
  const result = {
    ...variables,
    ...prompts
  };
  const responseSize = JSON.stringify(result).length;
  if (responseSize > 3e4) {
    logger.warn("Response size approaching Amazon Connect limit", {
      responseSize,
      configId: config.id,
      limit: 32768
    });
  }
  logger.info("Successfully transformed FlowConfig", {
    configId: config.id,
    language,
    channel,
    variableCount: Object.keys(variables).length,
    promptCount: Object.keys(prompts).length,
    responseSize
  });
  return result;
}
__name(transformFlowConfig, "transformFlowConfig");
function stripSSML(text) {
  return text.replace(/<[^>]*>/g, "").replace(/\s+/g, " ").trim();
}
__name(stripSSML, "stripSSML");

// backend/FlowConfig.ts
var env = process.env;
var client2 = new import_client_dynamodb.DynamoDBClient();
var docClient = import_lib_dynamodb.DynamoDBDocumentClient.from(client2);
var handler = /* @__PURE__ */ __name(async (event, context) => {
  logEvent(event, context);
  try {
    const method = event.httpMethod;
    const path = event.path;
    const pathParameters = event.pathParameters;
    const claims = event.requestContext.authorizer?.claims;
    if (!claims) {
      return respondObject(401, new Error("Unauthorized"));
    }
    if (method === "GET" && path === "/api/flow-config") {
      return await listFlowConfigs(event, claims);
    } else if (method === "GET" && pathParameters?.id) {
      return await getFlowConfig(pathParameters.id, claims);
    } else if (method === "POST" && path === "/api/flow-config/preview") {
      return await previewFlowConfig(event, claims);
    } else if (method === "POST" && pathParameters?.id) {
      return await saveFlowConfig(pathParameters.id, event, claims);
    } else if (method === "DELETE" && pathParameters?.id) {
      return await deleteFlowConfig(pathParameters.id, claims);
    }
    return respondMessage(404, "Not Found");
  } catch (error) {
    await sendError("Unhandled Error: api/flow-config", error);
    return respondError(error);
  }
}, "handler");
async function listFlowConfigs(event, claims) {
  try {
    const scanCommand = new import_lib_dynamodb.ScanCommand({
      TableName: env.FLOW_CONFIGS_TABLE_NAME
    });
    const response = await docClient.send(scanCommand);
    const flowConfigs = response.Items || [];
    const pattern = event.queryStringParameters?.pattern;
    let filteredConfigs = flowConfigs;
    if (pattern) {
      filteredConfigs = flowConfigs.filter(
        (config) => config.id.startsWith(pattern)
      );
    }
    const resultItems = [];
    for (const config of filteredConfigs) {
      const accessLevel = await checkPermissions(claims, config.id, "Read");
      if (accessLevel) {
        resultItems.push({
          id: config.id,
          description: config.description,
          accessLevel
        });
      }
    }
    const result = { items: resultItems };
    return respondObject(200, result);
  } catch (error) {
    throw new Error(`Error listing flow configs: ${error}`);
  }
}
__name(listFlowConfigs, "listFlowConfigs");
async function getFlowConfig(flowConfigId, claims) {
  try {
    const accessLevel = await checkPermissions(claims, flowConfigId, "Read");
    if (!accessLevel) {
      return respondMessage(403, "Access denied");
    }
    const getCommand = new import_lib_dynamodb.GetCommand({
      TableName: env.FLOW_CONFIGS_TABLE_NAME,
      Key: { id: flowConfigId }
    });
    const response = await docClient.send(getCommand);
    if (!response.Item) {
      return respondMessage(404, "Flow Config not found");
    }
    return respondObject(200, response.Item);
  } catch (error) {
    throw new Error(`Error getting flow config ${flowConfigId}: ${error}`);
  }
}
__name(getFlowConfig, "getFlowConfig");
async function saveFlowConfig(flowConfigId, event, claims) {
  if (!event.body) {
    return respondMessage(400, "Request body required");
  }
  let body;
  try {
    body = JSON.parse(event.body);
  } catch (error) {
    return respondMessage(400, "Invalid JSON in request body");
  }
  body.id = flowConfigId;
  if (!body.description || !body.variables || !body.prompts) {
    return respondMessage(
      400,
      "Missing required fields: description, variables, prompts"
    );
  }
  for (const [key, value] of Object.entries(body.variables)) {
    if (typeof value !== "string") {
      return respondMessage(400, `Variable ${key} must be a string`);
    }
  }
  for (const [promptName, promptData] of Object.entries(body.prompts)) {
    for (const [lang, langData] of Object.entries(promptData)) {
      if (!langData.voice) {
        return respondMessage(
          400,
          `Prompt ${promptName} for language ${lang} must have a voice variant`
        );
      }
    }
  }
  const itemSize = JSON.stringify(body).length;
  if (itemSize > 38e4) {
    return respondMessage(413, "Flow config exceeds maximum size limit");
  }
  try {
    const getCommand = new import_lib_dynamodb.GetCommand({
      TableName: env.FLOW_CONFIGS_TABLE_NAME,
      Key: { id: flowConfigId }
    });
    const response = await docClient.send(getCommand);
    const existingConfig = response.Item;
    const action = existingConfig ? "Edit" : "Create";
    const accessLevel = await checkPermissions(claims, flowConfigId, action);
    if (!accessLevel) {
      return respondMessage(403, "Access denied");
    }
    const putCommand = new import_lib_dynamodb.PutCommand({
      TableName: env.FLOW_CONFIGS_TABLE_NAME,
      Item: body
    });
    await docClient.send(putCommand);
    const statusCode = existingConfig ? 200 : 201;
    return respondObject(statusCode, body);
  } catch (error) {
    throw new Error(`Error saving flow config ${flowConfigId}: ${error}`);
  }
}
__name(saveFlowConfig, "saveFlowConfig");
async function deleteFlowConfig(flowConfigId, claims) {
  try {
    const accessLevel = await checkPermissions(claims, flowConfigId, "Delete");
    if (!accessLevel) {
      return respondMessage(403, "Access denied");
    }
    const getCommand = new import_lib_dynamodb.GetCommand({
      TableName: env.FLOW_CONFIGS_TABLE_NAME,
      Key: { id: flowConfigId }
    });
    const response = await docClient.send(getCommand);
    if (!response.Item) {
      return respondMessage(404, "Flow Config not found");
    }
    const deleteCommand = new import_lib_dynamodb.DeleteCommand({
      TableName: env.FLOW_CONFIGS_TABLE_NAME,
      Key: { id: flowConfigId }
    });
    await docClient.send(deleteCommand);
    return respondMessage(204, "");
  } catch (error) {
    throw new Error(`Error deleting flow config ${flowConfigId}: ${error}`);
  }
}
__name(deleteFlowConfig, "deleteFlowConfig");
async function previewFlowConfig(event, claims) {
  try {
    if (!event.body) {
      return respondMessage(400, "Request body required");
    }
    let requestData;
    try {
      requestData = JSON.parse(event.body);
    } catch (error) {
      return respondMessage(400, "Invalid JSON in request body");
    }
    const { flowConfig, lang: language, channel } = requestData;
    if (!flowConfig) {
      return respondMessage(400, "flowConfig is required");
    }
    if (!language) {
      return respondMessage(400, "lang is required");
    }
    if (!channel) {
      return respondMessage(400, "channel is required");
    }
    if (!/^[a-z]{2}-[A-Z]{2}$/.test(language)) {
      return respondMessage(
        400,
        "Invalid language code format. Expected format: en-US"
      );
    }
    if (!["voice", "chat"].includes(channel)) {
      return respondMessage(400, 'Invalid channel. Must be "voice" or "chat"');
    }
    if (!flowConfig.id || !flowConfig.description || !flowConfig.variables || !flowConfig.prompts) {
      return respondMessage(
        400,
        "FlowConfig must have id, description, variables, and prompts"
      );
    }
    const accessLevel = await checkPermissions(claims, flowConfig.id, "Read");
    if (!accessLevel) {
      return respondMessage(403, "Access denied");
    }
    const result = transformFlowConfig(flowConfig, {
      language,
      channel
    });
    return respondObject(200, result);
  } catch (error) {
    throw new Error(`Error previewing flow config: ${error}`);
  }
}
__name(previewFlowConfig, "previewFlowConfig");
async function checkPermissions(_claims, flowConfigId, action) {
  try {
    return Promise.resolve("Full");
  } catch (error) {
    console.error(
      `Error checking permissions for ${flowConfigId}, action ${action}:`,
      error
    );
    return null;
  }
}
__name(checkPermissions, "checkPermissions");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
//# sourceMappingURL=index.js.map
