"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// backend/GetConfig.ts
var GetConfig_exports = {};
__export(GetConfig_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(GetConfig_exports);
var import_client_dynamodb = require("@aws-sdk/client-dynamodb");
var import_lib_dynamodb = require("@aws-sdk/lib-dynamodb");

// backend/shared/logger.ts
var import_logger = require("@aws-lambda-powertools/logger");
var logger = new import_logger.Logger();

// backend/shared/transformFlowConfig.ts
function transformFlowConfig(config, options) {
  const { language, channel } = options;
  logger.debug("Transforming flow config", {
    configId: config.id,
    language,
    channel
  });
  const variables = config.variables || {};
  const prompts = {};
  const rawPrompts = config.prompts || {};
  for (const [promptName, promptData] of Object.entries(rawPrompts)) {
    if (language in promptData) {
      const langData = promptData[language];
      if (channel === "chat" && langData.chat) {
        prompts[promptName] = langData.chat;
      } else if (langData.voice) {
        if (channel === "chat") {
          prompts[promptName] = stripSSML(langData.voice);
        } else {
          prompts[promptName] = langData.voice;
        }
      }
    } else {
      logger.warn(`Language ${language} not found for prompt ${promptName}`, {
        configId: config.id,
        promptName,
        availableLanguages: Object.keys(promptData)
      });
    }
  }
  const result = {
    ...variables,
    ...prompts
  };
  const responseSize = JSON.stringify(result).length;
  if (responseSize > 3e4) {
    logger.warn("Response size approaching Amazon Connect limit", {
      responseSize,
      configId: config.id,
      limit: 32768
    });
  }
  logger.info("Successfully transformed FlowConfig", {
    configId: config.id,
    language,
    channel,
    variableCount: Object.keys(variables).length,
    promptCount: Object.keys(prompts).length,
    responseSize
  });
  return result;
}
__name(transformFlowConfig, "transformFlowConfig");
function stripSSML(text) {
  return text.replace(/<[^>]*>/g, "").replace(/\s+/g, " ").trim();
}
__name(stripSSML, "stripSSML");

// backend/GetConfig.ts
var client = new import_client_dynamodb.DynamoDBClient({ region: process.env.AWS_REGION });
var docClient = import_lib_dynamodb.DynamoDBDocumentClient.from(client);
var handler = /* @__PURE__ */ __name(async (event) => {
  logger.info("GetConfig Lambda invoked", { event });
  try {
    const configId = event?.Details?.Parameters?.id ?? event.id;
    const language = event?.Details?.Parameters?.lang ?? event?.Details?.ContactData?.Attributes?.lang ?? event.lang ?? "en-US";
    const channel = (event?.Details?.ContactData?.Channel?.toString() ?? event.channel ?? "voice").toLowerCase();
    if (!configId) {
      throw new Error("Missing required parameter: id");
    }
    logger.info("Retrieving flow config", { configId, language, channel });
    const command = new import_lib_dynamodb.GetCommand({
      TableName: process.env.FLOW_CONFIGS_TABLE_NAME,
      Key: { id: configId }
    });
    const response = await docClient.send(command);
    if (!response.Item) {
      logger.warn("Flow config not found", { configId });
      throw new Error(`Flow config with id ${configId} not found`);
    }
    const config = response.Item;
    logger.debug("Retrieved flow config", { config });
    const result = transformFlowConfig(config, {
      language,
      channel
    });
    return result;
  } catch (error) {
    logger.error("Error in GetConfig Lambda", error);
    throw error;
  }
}, "handler");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
//# sourceMappingURL=index.js.map
