"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// backend/Init.ts
var Init_exports = {};
__export(Init_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(Init_exports);
var import_client_cloudformation = require("@aws-sdk/client-cloudformation");

// backend/shared/logger.ts
var import_logger = require("@aws-lambda-powertools/logger");
var logger = new import_logger.Logger();
var logEvent = /* @__PURE__ */ __name((event, context) => {
  if (context) {
    logger.addContext(context);
  }
  if (event) {
    logger.logEventIfEnabled(event);
  }
  const ContactData = event?.Details?.ContactData;
  if (ContactData) {
    const { InstanceARN, ContactId } = ContactData;
    logger.appendKeys({
      connectInstanceId: InstanceARN?.split("/").pop(),
      connectContactId: ContactId
    });
  }
}, "logEvent");

// backend/shared/respond.ts
var respond = /* @__PURE__ */ __name((statusCode, body) => ({
  statusCode,
  body
}), "respond");
var respondObject = /* @__PURE__ */ __name((statusCode, obj) => respond(statusCode, JSON.stringify(obj)), "respondObject");
var respondMessage = /* @__PURE__ */ __name((statusCode, message) => respondObject(statusCode, { message }), "respondMessage");
var respondError = /* @__PURE__ */ __name((error) => {
  logger.error("Unhandled Server Error", error);
  return respondMessage(500, error.message);
}, "respondError");

// backend/shared/snsClient.ts
var import_client_sns = require("@aws-sdk/client-sns");

// backend/shared/getVar.ts
function getVar(name, defaultValue) {
  const val = process.env[name] || defaultValue;
  if (!val) {
    throw new Error(`Environment variable "${name}" is not defined`);
  }
  return val;
}
__name(getVar, "getVar");

// backend/shared/snsClient.ts
var client = new import_client_sns.SNSClient();
var ALERT_TOPIC_ARN = getVar("ALERT_TOPIC_ARN");
var sendError = /* @__PURE__ */ __name(async (subject, error) => {
  try {
    await client.send(
      new import_client_sns.PublishCommand({
        TopicArn: ALERT_TOPIC_ARN,
        Subject: subject,
        Message: typeof error === "string" ? error : error.message
      })
    );
  } catch (error2) {
    logger.error("Error sending message to SNS", {
      error: error2,
      sns: { subject, message: error2 }
    });
  }
}, "sendError");

// backend/Init.ts
var env = process.env;
var cloudformationClient = new import_client_cloudformation.CloudFormationClient();
var response = void 0;
var getStackOutputs = /* @__PURE__ */ __name(async (stackName) => {
  const stacks = await cloudformationClient.send(
    new import_client_cloudformation.DescribeStacksCommand({ StackName: stackName })
  );
  const stack = stacks.Stacks?.pop();
  if (!stack) {
    throw new Error(`Could not locate stack named ${env.stackName}`);
  }
  const outputs = {};
  stack.Outputs?.forEach(({ OutputKey = "", OutputValue = "" }) => {
    if (OutputKey) {
      outputs[OutputKey] = OutputValue;
    }
  });
  return {
    status: stack.StackStatus ?? "",
    outputs
  };
}, "getStackOutputs");
var handler = /* @__PURE__ */ __name(async (event, context) => {
  logEvent(event, context);
  try {
    if (!response) {
      const outputs = await getStackOutputs(env.stackName);
      response = {
        region: env.AWS_REGION ?? "us-east-1",
        userPoolId: env.userPoolId,
        clientId: outputs.outputs.UserPoolClientId
      };
    }
    return respondObject(200, response);
  } catch (error) {
    await sendError("Unhandled Error: api/init", error);
    return respondError(error);
  }
}, "handler");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
//# sourceMappingURL=index.js.map
