"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// backend/PreviewSpeech.ts
var PreviewSpeech_exports = {};
__export(PreviewSpeech_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(PreviewSpeech_exports);
var import_client_polly = require("@aws-sdk/client-polly");

// backend/shared/logger.ts
var import_logger = require("@aws-lambda-powertools/logger");
var logger = new import_logger.Logger();
var logEvent = /* @__PURE__ */ __name((event, context) => {
  if (context) {
    logger.addContext(context);
  }
  if (event) {
    logger.logEventIfEnabled(event);
  }
  const ContactData = event?.Details?.ContactData;
  if (ContactData) {
    const { InstanceARN, ContactId } = ContactData;
    logger.appendKeys({
      connectInstanceId: InstanceARN?.split("/").pop(),
      connectContactId: ContactId
    });
  }
}, "logEvent");

// backend/shared/respond.ts
var respond = /* @__PURE__ */ __name((statusCode, body) => ({
  statusCode,
  body
}), "respond");
var respondObject = /* @__PURE__ */ __name((statusCode, obj) => respond(statusCode, JSON.stringify(obj)), "respondObject");
var respondMessage = /* @__PURE__ */ __name((statusCode, message) => respondObject(statusCode, { message }), "respondMessage");
var respondError = /* @__PURE__ */ __name((error) => {
  logger.error("Unhandled Server Error", error);
  return respondMessage(500, error.message);
}, "respondError");

// backend/PreviewSpeech.ts
var pollyClient = new import_client_polly.PollyClient();
var handler = /* @__PURE__ */ __name(async (event, context) => {
  logEvent(event, context);
  try {
    if (!event.body) {
      return respondMessage(400, "Request body required");
    }
    const request = JSON.parse(event.body);
    if (!request.text || !request.languageCode || !request.voiceId) {
      return respondMessage(
        400,
        "Missing required fields: text, languageCode, voiceId"
      );
    }
    if (request.text.length > 3e3) {
      return respondMessage(
        400,
        "Text exceeds maximum length of 3000 characters"
      );
    }
    if (!/^[a-z]{2}-[A-Z]{2}$/.test(request.languageCode)) {
      return respondMessage(
        400,
        "Invalid language code format. Expected format: en-US"
      );
    }
    logger.info("Synthesizing speech with Polly", {
      languageCode: request.languageCode,
      voiceId: request.voiceId,
      textLength: request.text.length,
      hasSSML: request.text.includes("<speak>")
    });
    const textType = request.text.includes("<speak>") ? "ssml" : "text";
    const synthesizeSpeech = /* @__PURE__ */ __name(async (engine) => {
      return await pollyClient.send(
        new import_client_polly.SynthesizeSpeechCommand({
          Engine: engine,
          LanguageCode: request.languageCode,
          OutputFormat: "mp3",
          Text: request.text,
          TextType: textType,
          VoiceId: request.voiceId
        })
      );
    }, "synthesizeSpeech");
    let AudioStream;
    try {
      const neuralResponse = await synthesizeSpeech("neural");
      AudioStream = neuralResponse.AudioStream;
      logger.info("Used neural engine for voice synthesis", {
        voiceId: request.voiceId,
        languageCode: request.languageCode
      });
    } catch (neuralError) {
      logger.info("Neural engine not supported, falling back to standard", {
        voiceId: request.voiceId,
        languageCode: request.languageCode,
        neuralError: neuralError.message
      });
      const standardResponse = await synthesizeSpeech("standard");
      AudioStream = standardResponse.AudioStream;
      logger.info("Used standard engine for voice synthesis", {
        voiceId: request.voiceId,
        languageCode: request.languageCode
      });
    }
    if (!AudioStream) {
      throw new Error("No audio stream received from Polly");
    }
    const byteArray = await AudioStream.transformToByteArray();
    const buffer = Buffer.from(byteArray);
    const base64Audio = {
      Audio: buffer
    };
    logger.info("Speech synthesis completed", {
      audioSizeBytes: buffer.length
    });
    return {
      statusCode: 200,
      headers: {
        "Content-Type": "audio/mpeg",
        "Content-Disposition": 'attachment; filename="speech.mp3"',
        "Cache-Control": "no-cache"
      },
      body: JSON.stringify(base64Audio),
      isBase64Encoded: true
    };
  } catch (error) {
    logger.error("Error in PreviewSpeech Lambda", error);
    return respondError(error);
  }
}, "handler");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
//# sourceMappingURL=index.js.map
