"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// backend/SecurityProfileProvider.ts
var SecurityProfileProvider_exports = {};
__export(SecurityProfileProvider_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(SecurityProfileProvider_exports);
var import_client_connect = require("@aws-sdk/client-connect");

// backend/shared/logger.ts
var import_logger = require("@aws-lambda-powertools/logger");
var logger = new import_logger.Logger();
var logEvent = /* @__PURE__ */ __name((event, context) => {
  if (context) {
    logger.addContext(context);
  }
  if (event) {
    logger.logEventIfEnabled(event);
  }
  const ContactData = event?.Details?.ContactData;
  if (ContactData) {
    const { InstanceARN, ContactId } = ContactData;
    logger.appendKeys({
      connectInstanceId: InstanceARN?.split("/").pop(),
      connectContactId: ContactId
    });
  }
}, "logEvent");

// backend/SecurityProfileProvider.ts
var connectClient = new import_client_connect.ConnectClient();
var getProfileId = /* @__PURE__ */ __name(async (instanceId, name) => {
  let nextToken;
  do {
    const profiles = await connectClient.send(
      new import_client_connect.ListSecurityProfilesCommand({
        InstanceId: instanceId,
        NextToken: nextToken
      })
    );
    const profile = profiles.SecurityProfileSummaryList?.find(
      (x) => x.Name?.toLowerCase() === name.toLowerCase()
    );
    if (profile) {
      return profile.Arn;
    }
    nextToken = profiles.NextToken;
  } while (nextToken);
  return void 0;
}, "getProfileId");
var getProfileApplications = /* @__PURE__ */ __name(async (instanceId, profileArn) => {
  let apps = [];
  let nextToken;
  do {
    const result = await connectClient.send(
      new import_client_connect.ListSecurityProfileApplicationsCommand({
        InstanceId: instanceId,
        SecurityProfileId: profileArn
      })
    );
    apps = apps.concat(result.Applications ?? []);
    nextToken = result.NextToken;
  } while (nextToken);
  return apps;
}, "getProfileApplications");
var upsertAppAccess = /* @__PURE__ */ __name(async (instanceId, profileArn, namespace, permissions) => {
  const apps = await getProfileApplications(instanceId, profileArn);
  let app = apps.find((x) => x.Namespace === namespace);
  if (!app) {
    app = {
      Namespace: namespace,
      ApplicationPermissions: permissions
    };
    apps.push(app);
  }
  app.ApplicationPermissions = permissions;
  await connectClient.send(
    new import_client_connect.UpdateSecurityProfileCommand({
      InstanceId: instanceId,
      SecurityProfileId: profileArn,
      Applications: apps
    })
  );
}, "upsertAppAccess");
var deleteAppAccess = /* @__PURE__ */ __name(async (instanceId, profileArn, namespace) => {
  const apps = await getProfileApplications(instanceId, profileArn);
  await connectClient.send(
    new import_client_connect.UpdateSecurityProfileCommand({
      InstanceId: instanceId,
      SecurityProfileId: profileArn,
      Applications: apps.filter((x) => x.Namespace !== namespace)
    })
  );
}, "deleteAppAccess");
var allowApplication = /* @__PURE__ */ __name(async (event) => {
  const { RequestType, ResourceProperties } = event;
  const { connectInstanceArn, namespace, permissions, securityProfileName } = ResourceProperties;
  const instanceId = connectInstanceArn.split("/").pop();
  const profileArn = await getProfileId(instanceId, securityProfileName);
  if (!profileArn) {
    logger.error(
      `Unable to locate security profile named ${securityProfileName}`
    );
    return;
  }
  if (RequestType === "Delete") {
    await deleteAppAccess(instanceId, profileArn, namespace);
  } else {
    await upsertAppAccess(instanceId, profileArn, namespace, permissions);
  }
  return { PhysicalResourceId: namespace };
}, "allowApplication");
var handler = /* @__PURE__ */ __name(async (event, context) => {
  logEvent(event, context);
  const { ResourceType } = event;
  try {
    if (ResourceType === "Custom::AllowApplication") {
      return await allowApplication(event);
    } else {
      throw new Error(`Unknown Resource Type: ${ResourceType}`);
    }
  } catch (error) {
    logger.error("Unhandled Error", error);
    throw error;
  }
}, "handler");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
//# sourceMappingURL=index.js.map
