import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { CompleteAttachedFileUploadRequest, CompleteAttachedFileUploadResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link CompleteAttachedFileUploadCommand}.
 */
export interface CompleteAttachedFileUploadCommandInput extends CompleteAttachedFileUploadRequest {
}
/**
 * @public
 *
 * The output of {@link CompleteAttachedFileUploadCommand}.
 */
export interface CompleteAttachedFileUploadCommandOutput extends CompleteAttachedFileUploadResponse, __MetadataBearer {
}
declare const CompleteAttachedFileUploadCommand_base: {
    new (input: CompleteAttachedFileUploadCommandInput): import("@smithy/smithy-client").CommandImpl<CompleteAttachedFileUploadCommandInput, CompleteAttachedFileUploadCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: CompleteAttachedFileUploadCommandInput): import("@smithy/smithy-client").CommandImpl<CompleteAttachedFileUploadCommandInput, CompleteAttachedFileUploadCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Allows you to confirm that the attached file has been uploaded using the pre-signed URL
 *    provided in the StartAttachedFileUpload API.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, CompleteAttachedFileUploadCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, CompleteAttachedFileUploadCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // CompleteAttachedFileUploadRequest
 *   InstanceId: "STRING_VALUE", // required
 *   FileId: "STRING_VALUE", // required
 *   AssociatedResourceArn: "STRING_VALUE", // required
 * };
 * const command = new CompleteAttachedFileUploadCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param CompleteAttachedFileUploadCommandInput - {@link CompleteAttachedFileUploadCommandInput}
 * @returns {@link CompleteAttachedFileUploadCommandOutput}
 * @see {@link CompleteAttachedFileUploadCommandInput} for command's `input` shape.
 * @see {@link CompleteAttachedFileUploadCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient permissions to perform this action.</p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class CompleteAttachedFileUploadCommand extends CompleteAttachedFileUploadCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: CompleteAttachedFileUploadRequest;
            output: {};
        };
        sdk: {
            input: CompleteAttachedFileUploadCommandInput;
            output: CompleteAttachedFileUploadCommandOutput;
        };
    };
}
