import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { CreateParticipantRequest, CreateParticipantResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link CreateParticipantCommand}.
 */
export interface CreateParticipantCommandInput extends CreateParticipantRequest {
}
/**
 * @public
 *
 * The output of {@link CreateParticipantCommand}.
 */
export interface CreateParticipantCommandOutput extends CreateParticipantResponse, __MetadataBearer {
}
declare const CreateParticipantCommand_base: {
    new (input: CreateParticipantCommandInput): import("@smithy/smithy-client").CommandImpl<CreateParticipantCommandInput, CreateParticipantCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: CreateParticipantCommandInput): import("@smithy/smithy-client").CommandImpl<CreateParticipantCommandInput, CreateParticipantCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Adds a new participant into an on-going chat contact. For more information, see <a href="https://docs.aws.amazon.com/connect/latest/adminguide/chat-customize-flow.html">Customize chat
 *     flow experiences by integrating custom participants</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, CreateParticipantCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, CreateParticipantCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // CreateParticipantRequest
 *   InstanceId: "STRING_VALUE", // required
 *   ContactId: "STRING_VALUE", // required
 *   ClientToken: "STRING_VALUE",
 *   ParticipantDetails: { // ParticipantDetailsToAdd
 *     ParticipantRole: "AGENT" || "CUSTOMER" || "SYSTEM" || "CUSTOM_BOT" || "SUPERVISOR",
 *     DisplayName: "STRING_VALUE",
 *   },
 * };
 * const command = new CreateParticipantCommand(input);
 * const response = await client.send(command);
 * // { // CreateParticipantResponse
 * //   ParticipantCredentials: { // ParticipantTokenCredentials
 * //     ParticipantToken: "STRING_VALUE",
 * //     Expiry: "STRING_VALUE",
 * //   },
 * //   ParticipantId: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param CreateParticipantCommandInput - {@link CreateParticipantCommandInput}
 * @returns {@link CreateParticipantCommandOutput}
 * @see {@link CreateParticipantCommandInput} for command's `input` shape.
 * @see {@link CreateParticipantCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>The service quota has been exceeded.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class CreateParticipantCommand extends CreateParticipantCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: CreateParticipantRequest;
            output: CreateParticipantResponse;
        };
        sdk: {
            input: CreateParticipantCommandInput;
            output: CreateParticipantCommandOutput;
        };
    };
}
