import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { CreatePredefinedAttributeRequest } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link CreatePredefinedAttributeCommand}.
 */
export interface CreatePredefinedAttributeCommandInput extends CreatePredefinedAttributeRequest {
}
/**
 * @public
 *
 * The output of {@link CreatePredefinedAttributeCommand}.
 */
export interface CreatePredefinedAttributeCommandOutput extends __MetadataBearer {
}
declare const CreatePredefinedAttributeCommand_base: {
    new (input: CreatePredefinedAttributeCommandInput): import("@smithy/smithy-client").CommandImpl<CreatePredefinedAttributeCommandInput, CreatePredefinedAttributeCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: CreatePredefinedAttributeCommandInput): import("@smithy/smithy-client").CommandImpl<CreatePredefinedAttributeCommandInput, CreatePredefinedAttributeCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Creates a new predefined attribute for the specified Amazon Connect instance. <i>Predefined
 *     attributes</i> are attributes in an Amazon Connect instance that can be used to route
 *    contacts to an agent or pools of agents within a queue. For more information, see <a href="https://docs.aws.amazon.com/connect/latest/adminguide/predefined-attributes.html">Create
 *     predefined attributes for routing contacts to agents</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, CreatePredefinedAttributeCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, CreatePredefinedAttributeCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // CreatePredefinedAttributeRequest
 *   InstanceId: "STRING_VALUE", // required
 *   Name: "STRING_VALUE", // required
 *   Values: { // PredefinedAttributeValues Union: only one key present
 *     StringList: [ // PredefinedAttributeStringValuesList
 *       "STRING_VALUE",
 *     ],
 *   },
 * };
 * const command = new CreatePredefinedAttributeCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param CreatePredefinedAttributeCommandInput - {@link CreatePredefinedAttributeCommandInput}
 * @returns {@link CreatePredefinedAttributeCommandOutput}
 * @see {@link CreatePredefinedAttributeCommandInput} for command's `input` shape.
 * @see {@link CreatePredefinedAttributeCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link DuplicateResourceException} (client fault)
 *  <p>A resource with the specified name already exists.</p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>The allowed limit for the resource has been exceeded.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class CreatePredefinedAttributeCommand extends CreatePredefinedAttributeCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: CreatePredefinedAttributeRequest;
            output: {};
        };
        sdk: {
            input: CreatePredefinedAttributeCommandInput;
            output: CreatePredefinedAttributeCommandOutput;
        };
    };
}
