import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { DeactivateEvaluationFormRequest, DeactivateEvaluationFormResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeactivateEvaluationFormCommand}.
 */
export interface DeactivateEvaluationFormCommandInput extends DeactivateEvaluationFormRequest {
}
/**
 * @public
 *
 * The output of {@link DeactivateEvaluationFormCommand}.
 */
export interface DeactivateEvaluationFormCommandOutput extends DeactivateEvaluationFormResponse, __MetadataBearer {
}
declare const DeactivateEvaluationFormCommand_base: {
    new (input: DeactivateEvaluationFormCommandInput): import("@smithy/smithy-client").CommandImpl<DeactivateEvaluationFormCommandInput, DeactivateEvaluationFormCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DeactivateEvaluationFormCommandInput): import("@smithy/smithy-client").CommandImpl<DeactivateEvaluationFormCommandInput, DeactivateEvaluationFormCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deactivates an evaluation form in the specified Amazon Connect instance. After a form is deactivated,
 *    it is no longer available for users to start new evaluations based on the form. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, DeactivateEvaluationFormCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, DeactivateEvaluationFormCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // DeactivateEvaluationFormRequest
 *   InstanceId: "STRING_VALUE", // required
 *   EvaluationFormId: "STRING_VALUE", // required
 *   EvaluationFormVersion: Number("int"), // required
 * };
 * const command = new DeactivateEvaluationFormCommand(input);
 * const response = await client.send(command);
 * // { // DeactivateEvaluationFormResponse
 * //   EvaluationFormId: "STRING_VALUE", // required
 * //   EvaluationFormArn: "STRING_VALUE", // required
 * //   EvaluationFormVersion: Number("int"), // required
 * // };
 *
 * ```
 *
 * @param DeactivateEvaluationFormCommandInput - {@link DeactivateEvaluationFormCommandInput}
 * @returns {@link DeactivateEvaluationFormCommandOutput}
 * @see {@link DeactivateEvaluationFormCommandInput} for command's `input` shape.
 * @see {@link DeactivateEvaluationFormCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link ResourceConflictException} (client fault)
 *  <p>A resource already has that name.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class DeactivateEvaluationFormCommand extends DeactivateEvaluationFormCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeactivateEvaluationFormRequest;
            output: DeactivateEvaluationFormResponse;
        };
        sdk: {
            input: DeactivateEvaluationFormCommandInput;
            output: DeactivateEvaluationFormCommandOutput;
        };
    };
}
