import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { DeleteHoursOfOperationRequest } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteHoursOfOperationCommand}.
 */
export interface DeleteHoursOfOperationCommandInput extends DeleteHoursOfOperationRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteHoursOfOperationCommand}.
 */
export interface DeleteHoursOfOperationCommandOutput extends __MetadataBearer {
}
declare const DeleteHoursOfOperationCommand_base: {
    new (input: DeleteHoursOfOperationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteHoursOfOperationCommandInput, DeleteHoursOfOperationCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DeleteHoursOfOperationCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteHoursOfOperationCommandInput, DeleteHoursOfOperationCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>This API is in preview release for Amazon Connect and is subject to change.</p>
 *          <p>Deletes an hours of operation.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, DeleteHoursOfOperationCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, DeleteHoursOfOperationCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // DeleteHoursOfOperationRequest
 *   InstanceId: "STRING_VALUE", // required
 *   HoursOfOperationId: "STRING_VALUE", // required
 * };
 * const command = new DeleteHoursOfOperationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteHoursOfOperationCommandInput - {@link DeleteHoursOfOperationCommandInput}
 * @returns {@link DeleteHoursOfOperationCommandOutput}
 * @see {@link DeleteHoursOfOperationCommandInput} for command's `input` shape.
 * @see {@link DeleteHoursOfOperationCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class DeleteHoursOfOperationCommand extends DeleteHoursOfOperationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteHoursOfOperationRequest;
            output: {};
        };
        sdk: {
            input: DeleteHoursOfOperationCommandInput;
            output: DeleteHoursOfOperationCommandOutput;
        };
    };
}
