import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { DeleteHoursOfOperationOverrideRequest } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteHoursOfOperationOverrideCommand}.
 */
export interface DeleteHoursOfOperationOverrideCommandInput extends DeleteHoursOfOperationOverrideRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteHoursOfOperationOverrideCommand}.
 */
export interface DeleteHoursOfOperationOverrideCommandOutput extends __MetadataBearer {
}
declare const DeleteHoursOfOperationOverrideCommand_base: {
    new (input: DeleteHoursOfOperationOverrideCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteHoursOfOperationOverrideCommandInput, DeleteHoursOfOperationOverrideCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DeleteHoursOfOperationOverrideCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteHoursOfOperationOverrideCommandInput, DeleteHoursOfOperationOverrideCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes an hours of operation override in an Amazon Connect hours of operation
 *    resource</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, DeleteHoursOfOperationOverrideCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, DeleteHoursOfOperationOverrideCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // DeleteHoursOfOperationOverrideRequest
 *   InstanceId: "STRING_VALUE", // required
 *   HoursOfOperationId: "STRING_VALUE", // required
 *   HoursOfOperationOverrideId: "STRING_VALUE", // required
 * };
 * const command = new DeleteHoursOfOperationOverrideCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteHoursOfOperationOverrideCommandInput - {@link DeleteHoursOfOperationOverrideCommandInput}
 * @returns {@link DeleteHoursOfOperationOverrideCommandOutput}
 * @see {@link DeleteHoursOfOperationOverrideCommandInput} for command's `input` shape.
 * @see {@link DeleteHoursOfOperationOverrideCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class DeleteHoursOfOperationOverrideCommand extends DeleteHoursOfOperationOverrideCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteHoursOfOperationOverrideRequest;
            output: {};
        };
        sdk: {
            input: DeleteHoursOfOperationOverrideCommandInput;
            output: DeleteHoursOfOperationOverrideCommandOutput;
        };
    };
}
