import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { DeleteRoutingProfileRequest } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteRoutingProfileCommand}.
 */
export interface DeleteRoutingProfileCommandInput extends DeleteRoutingProfileRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteRoutingProfileCommand}.
 */
export interface DeleteRoutingProfileCommandOutput extends __MetadataBearer {
}
declare const DeleteRoutingProfileCommand_base: {
    new (input: DeleteRoutingProfileCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteRoutingProfileCommandInput, DeleteRoutingProfileCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DeleteRoutingProfileCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteRoutingProfileCommandInput, DeleteRoutingProfileCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes a routing profile.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, DeleteRoutingProfileCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, DeleteRoutingProfileCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // DeleteRoutingProfileRequest
 *   InstanceId: "STRING_VALUE", // required
 *   RoutingProfileId: "STRING_VALUE", // required
 * };
 * const command = new DeleteRoutingProfileCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteRoutingProfileCommandInput - {@link DeleteRoutingProfileCommandInput}
 * @returns {@link DeleteRoutingProfileCommandOutput}
 * @see {@link DeleteRoutingProfileCommandInput} for command's `input` shape.
 * @see {@link DeleteRoutingProfileCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceInUseException} (client fault)
 *  <p>That resource is already in use. Please try another.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class DeleteRoutingProfileCommand extends DeleteRoutingProfileCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteRoutingProfileRequest;
            output: {};
        };
        sdk: {
            input: DeleteRoutingProfileCommandInput;
            output: DeleteRoutingProfileCommandOutput;
        };
    };
}
