import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { DeleteTaskTemplateRequest, DeleteTaskTemplateResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteTaskTemplateCommand}.
 */
export interface DeleteTaskTemplateCommandInput extends DeleteTaskTemplateRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteTaskTemplateCommand}.
 */
export interface DeleteTaskTemplateCommandOutput extends DeleteTaskTemplateResponse, __MetadataBearer {
}
declare const DeleteTaskTemplateCommand_base: {
    new (input: DeleteTaskTemplateCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteTaskTemplateCommandInput, DeleteTaskTemplateCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DeleteTaskTemplateCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteTaskTemplateCommandInput, DeleteTaskTemplateCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes the task template.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, DeleteTaskTemplateCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, DeleteTaskTemplateCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // DeleteTaskTemplateRequest
 *   InstanceId: "STRING_VALUE", // required
 *   TaskTemplateId: "STRING_VALUE", // required
 * };
 * const command = new DeleteTaskTemplateCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteTaskTemplateCommandInput - {@link DeleteTaskTemplateCommandInput}
 * @returns {@link DeleteTaskTemplateCommandOutput}
 * @see {@link DeleteTaskTemplateCommandInput} for command's `input` shape.
 * @see {@link DeleteTaskTemplateCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class DeleteTaskTemplateCommand extends DeleteTaskTemplateCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteTaskTemplateRequest;
            output: {};
        };
        sdk: {
            input: DeleteTaskTemplateCommandInput;
            output: DeleteTaskTemplateCommandOutput;
        };
    };
}
