import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { DescribePredefinedAttributeRequest, DescribePredefinedAttributeResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribePredefinedAttributeCommand}.
 */
export interface DescribePredefinedAttributeCommandInput extends DescribePredefinedAttributeRequest {
}
/**
 * @public
 *
 * The output of {@link DescribePredefinedAttributeCommand}.
 */
export interface DescribePredefinedAttributeCommandOutput extends DescribePredefinedAttributeResponse, __MetadataBearer {
}
declare const DescribePredefinedAttributeCommand_base: {
    new (input: DescribePredefinedAttributeCommandInput): import("@smithy/smithy-client").CommandImpl<DescribePredefinedAttributeCommandInput, DescribePredefinedAttributeCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: DescribePredefinedAttributeCommandInput): import("@smithy/smithy-client").CommandImpl<DescribePredefinedAttributeCommandInput, DescribePredefinedAttributeCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describes a predefined attribute for the specified Amazon Connect instance. <i>Predefined
 *     attributes</i> are attributes in an Amazon Connect instance that can be used to route
 *    contacts to an agent or pools of agents within a queue. For more information, see <a href="https://docs.aws.amazon.com/connect/latest/adminguide/predefined-attributes.html">Create
 *     predefined attributes for routing contacts to agents</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, DescribePredefinedAttributeCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, DescribePredefinedAttributeCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // DescribePredefinedAttributeRequest
 *   InstanceId: "STRING_VALUE", // required
 *   Name: "STRING_VALUE", // required
 * };
 * const command = new DescribePredefinedAttributeCommand(input);
 * const response = await client.send(command);
 * // { // DescribePredefinedAttributeResponse
 * //   PredefinedAttribute: { // PredefinedAttribute
 * //     Name: "STRING_VALUE",
 * //     Values: { // PredefinedAttributeValues Union: only one key present
 * //       StringList: [ // PredefinedAttributeStringValuesList
 * //         "STRING_VALUE",
 * //       ],
 * //     },
 * //     LastModifiedTime: new Date("TIMESTAMP"),
 * //     LastModifiedRegion: "STRING_VALUE",
 * //   },
 * // };
 *
 * ```
 *
 * @param DescribePredefinedAttributeCommandInput - {@link DescribePredefinedAttributeCommandInput}
 * @returns {@link DescribePredefinedAttributeCommandOutput}
 * @see {@link DescribePredefinedAttributeCommandInput} for command's `input` shape.
 * @see {@link DescribePredefinedAttributeCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class DescribePredefinedAttributeCommand extends DescribePredefinedAttributeCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribePredefinedAttributeRequest;
            output: DescribePredefinedAttributeResponse;
        };
        sdk: {
            input: DescribePredefinedAttributeCommandInput;
            output: DescribePredefinedAttributeCommandOutput;
        };
    };
}
