import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { GetEffectiveHoursOfOperationsRequest, GetEffectiveHoursOfOperationsResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetEffectiveHoursOfOperationsCommand}.
 */
export interface GetEffectiveHoursOfOperationsCommandInput extends GetEffectiveHoursOfOperationsRequest {
}
/**
 * @public
 *
 * The output of {@link GetEffectiveHoursOfOperationsCommand}.
 */
export interface GetEffectiveHoursOfOperationsCommandOutput extends GetEffectiveHoursOfOperationsResponse, __MetadataBearer {
}
declare const GetEffectiveHoursOfOperationsCommand_base: {
    new (input: GetEffectiveHoursOfOperationsCommandInput): import("@smithy/smithy-client").CommandImpl<GetEffectiveHoursOfOperationsCommandInput, GetEffectiveHoursOfOperationsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: GetEffectiveHoursOfOperationsCommandInput): import("@smithy/smithy-client").CommandImpl<GetEffectiveHoursOfOperationsCommandInput, GetEffectiveHoursOfOperationsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Get the hours of operations with the effective override applied.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, GetEffectiveHoursOfOperationsCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, GetEffectiveHoursOfOperationsCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // GetEffectiveHoursOfOperationsRequest
 *   InstanceId: "STRING_VALUE", // required
 *   HoursOfOperationId: "STRING_VALUE", // required
 *   FromDate: "STRING_VALUE", // required
 *   ToDate: "STRING_VALUE", // required
 * };
 * const command = new GetEffectiveHoursOfOperationsCommand(input);
 * const response = await client.send(command);
 * // { // GetEffectiveHoursOfOperationsResponse
 * //   EffectiveHoursOfOperationList: [ // EffectiveHoursOfOperationList
 * //     { // EffectiveHoursOfOperations
 * //       Date: "STRING_VALUE",
 * //       OperationalHours: [ // OperationalHours
 * //         { // OperationalHour
 * //           Start: { // OverrideTimeSlice
 * //             Hours: Number("int"), // required
 * //             Minutes: Number("int"), // required
 * //           },
 * //           End: {
 * //             Hours: Number("int"), // required
 * //             Minutes: Number("int"), // required
 * //           },
 * //         },
 * //       ],
 * //     },
 * //   ],
 * //   TimeZone: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param GetEffectiveHoursOfOperationsCommandInput - {@link GetEffectiveHoursOfOperationsCommandInput}
 * @returns {@link GetEffectiveHoursOfOperationsCommandOutput}
 * @see {@link GetEffectiveHoursOfOperationsCommandInput} for command's `input` shape.
 * @see {@link GetEffectiveHoursOfOperationsCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class GetEffectiveHoursOfOperationsCommand extends GetEffectiveHoursOfOperationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetEffectiveHoursOfOperationsRequest;
            output: GetEffectiveHoursOfOperationsResponse;
        };
        sdk: {
            input: GetEffectiveHoursOfOperationsCommandInput;
            output: GetEffectiveHoursOfOperationsCommandOutput;
        };
    };
}
