import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { GetFlowAssociationRequest, GetFlowAssociationResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetFlowAssociationCommand}.
 */
export interface GetFlowAssociationCommandInput extends GetFlowAssociationRequest {
}
/**
 * @public
 *
 * The output of {@link GetFlowAssociationCommand}.
 */
export interface GetFlowAssociationCommandOutput extends GetFlowAssociationResponse, __MetadataBearer {
}
declare const GetFlowAssociationCommand_base: {
    new (input: GetFlowAssociationCommandInput): import("@smithy/smithy-client").CommandImpl<GetFlowAssociationCommandInput, GetFlowAssociationCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: GetFlowAssociationCommandInput): import("@smithy/smithy-client").CommandImpl<GetFlowAssociationCommandInput, GetFlowAssociationCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Retrieves the flow associated for a given resource.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, GetFlowAssociationCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, GetFlowAssociationCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // GetFlowAssociationRequest
 *   InstanceId: "STRING_VALUE", // required
 *   ResourceId: "STRING_VALUE", // required
 *   ResourceType: "SMS_PHONE_NUMBER" || "INBOUND_EMAIL" || "OUTBOUND_EMAIL" || "ANALYTICS_CONNECTOR" || "WHATSAPP_MESSAGING_PHONE_NUMBER", // required
 * };
 * const command = new GetFlowAssociationCommand(input);
 * const response = await client.send(command);
 * // { // GetFlowAssociationResponse
 * //   ResourceId: "STRING_VALUE",
 * //   FlowId: "STRING_VALUE",
 * //   ResourceType: "SMS_PHONE_NUMBER" || "INBOUND_EMAIL" || "OUTBOUND_EMAIL" || "ANALYTICS_CONNECTOR" || "WHATSAPP_MESSAGING_PHONE_NUMBER",
 * // };
 *
 * ```
 *
 * @param GetFlowAssociationCommandInput - {@link GetFlowAssociationCommandInput}
 * @returns {@link GetFlowAssociationCommandOutput}
 * @see {@link GetFlowAssociationCommandInput} for command's `input` shape.
 * @see {@link GetFlowAssociationCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient permissions to perform this action.</p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class GetFlowAssociationCommand extends GetFlowAssociationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetFlowAssociationRequest;
            output: GetFlowAssociationResponse;
        };
        sdk: {
            input: GetFlowAssociationCommandInput;
            output: GetFlowAssociationCommandOutput;
        };
    };
}
