import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { GetPromptFileRequest, GetPromptFileResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetPromptFileCommand}.
 */
export interface GetPromptFileCommandInput extends GetPromptFileRequest {
}
/**
 * @public
 *
 * The output of {@link GetPromptFileCommand}.
 */
export interface GetPromptFileCommandOutput extends GetPromptFileResponse, __MetadataBearer {
}
declare const GetPromptFileCommand_base: {
    new (input: GetPromptFileCommandInput): import("@smithy/smithy-client").CommandImpl<GetPromptFileCommandInput, GetPromptFileCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: GetPromptFileCommandInput): import("@smithy/smithy-client").CommandImpl<GetPromptFileCommandInput, GetPromptFileCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Gets the prompt file.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, GetPromptFileCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, GetPromptFileCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // GetPromptFileRequest
 *   InstanceId: "STRING_VALUE", // required
 *   PromptId: "STRING_VALUE", // required
 * };
 * const command = new GetPromptFileCommand(input);
 * const response = await client.send(command);
 * // { // GetPromptFileResponse
 * //   PromptPresignedUrl: "STRING_VALUE",
 * //   LastModifiedTime: new Date("TIMESTAMP"),
 * //   LastModifiedRegion: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param GetPromptFileCommandInput - {@link GetPromptFileCommandInput}
 * @returns {@link GetPromptFileCommandOutput}
 * @see {@link GetPromptFileCommandInput} for command's `input` shape.
 * @see {@link GetPromptFileCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class GetPromptFileCommand extends GetPromptFileCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetPromptFileRequest;
            output: GetPromptFileResponse;
        };
        sdk: {
            input: GetPromptFileCommandInput;
            output: GetPromptFileCommandOutput;
        };
    };
}
