import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListContactFlowVersionsRequest, ListContactFlowVersionsResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListContactFlowVersionsCommand}.
 */
export interface ListContactFlowVersionsCommandInput extends ListContactFlowVersionsRequest {
}
/**
 * @public
 *
 * The output of {@link ListContactFlowVersionsCommand}.
 */
export interface ListContactFlowVersionsCommandOutput extends ListContactFlowVersionsResponse, __MetadataBearer {
}
declare const ListContactFlowVersionsCommand_base: {
    new (input: ListContactFlowVersionsCommandInput): import("@smithy/smithy-client").CommandImpl<ListContactFlowVersionsCommandInput, ListContactFlowVersionsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListContactFlowVersionsCommandInput): import("@smithy/smithy-client").CommandImpl<ListContactFlowVersionsCommandInput, ListContactFlowVersionsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns all the available versions for the specified Amazon Connect instance and flow
 *    identifier.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListContactFlowVersionsCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListContactFlowVersionsCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListContactFlowVersionsRequest
 *   InstanceId: "STRING_VALUE", // required
 *   ContactFlowId: "STRING_VALUE", // required
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new ListContactFlowVersionsCommand(input);
 * const response = await client.send(command);
 * // { // ListContactFlowVersionsResponse
 * //   ContactFlowVersionSummaryList: [ // ContactFlowVersionSummaryList
 * //     { // ContactFlowVersionSummary
 * //       Arn: "STRING_VALUE",
 * //       VersionDescription: "STRING_VALUE",
 * //       Version: Number("long"),
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListContactFlowVersionsCommandInput - {@link ListContactFlowVersionsCommandInput}
 * @returns {@link ListContactFlowVersionsCommandOutput}
 * @see {@link ListContactFlowVersionsCommandInput} for command's `input` shape.
 * @see {@link ListContactFlowVersionsCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient permissions to perform this action.</p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListContactFlowVersionsCommand extends ListContactFlowVersionsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListContactFlowVersionsRequest;
            output: ListContactFlowVersionsResponse;
        };
        sdk: {
            input: ListContactFlowVersionsCommandInput;
            output: ListContactFlowVersionsCommandOutput;
        };
    };
}
