import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListContactReferencesRequest, ListContactReferencesResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListContactReferencesCommand}.
 */
export interface ListContactReferencesCommandInput extends ListContactReferencesRequest {
}
/**
 * @public
 *
 * The output of {@link ListContactReferencesCommand}.
 */
export interface ListContactReferencesCommandOutput extends ListContactReferencesResponse, __MetadataBearer {
}
declare const ListContactReferencesCommand_base: {
    new (input: ListContactReferencesCommandInput): import("@smithy/smithy-client").CommandImpl<ListContactReferencesCommandInput, ListContactReferencesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListContactReferencesCommandInput): import("@smithy/smithy-client").CommandImpl<ListContactReferencesCommandInput, ListContactReferencesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>This API is in preview release for Amazon Connect and is subject to change.</p>
 *          <p>For the specified <code>referenceTypes</code>, returns a list of references associated with
 *    the contact. <i>References</i> are links to documents that are related to a
 *    contact, such as emails, attachments, or URLs.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListContactReferencesCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListContactReferencesCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListContactReferencesRequest
 *   InstanceId: "STRING_VALUE", // required
 *   ContactId: "STRING_VALUE", // required
 *   ReferenceTypes: [ // ReferenceTypes // required
 *     "URL" || "ATTACHMENT" || "CONTACT_ANALYSIS" || "NUMBER" || "STRING" || "DATE" || "EMAIL" || "EMAIL_MESSAGE",
 *   ],
 *   NextToken: "STRING_VALUE",
 * };
 * const command = new ListContactReferencesCommand(input);
 * const response = await client.send(command);
 * // { // ListContactReferencesResponse
 * //   ReferenceSummaryList: [ // ReferenceSummaryList
 * //     { // ReferenceSummary Union: only one key present
 * //       Url: { // UrlReference
 * //         Name: "STRING_VALUE",
 * //         Value: "STRING_VALUE",
 * //       },
 * //       Attachment: { // AttachmentReference
 * //         Name: "STRING_VALUE",
 * //         Value: "STRING_VALUE",
 * //         Status: "AVAILABLE" || "DELETED" || "APPROVED" || "REJECTED" || "PROCESSING" || "FAILED",
 * //         Arn: "STRING_VALUE",
 * //       },
 * //       EmailMessage: { // EmailMessageReference
 * //         Name: "STRING_VALUE",
 * //         Arn: "STRING_VALUE",
 * //       },
 * //       String: { // StringReference
 * //         Name: "STRING_VALUE",
 * //         Value: "STRING_VALUE",
 * //       },
 * //       Number: { // NumberReference
 * //         Name: "STRING_VALUE",
 * //         Value: "STRING_VALUE",
 * //       },
 * //       Date: { // DateReference
 * //         Name: "STRING_VALUE",
 * //         Value: "STRING_VALUE",
 * //       },
 * //       Email: { // EmailReference
 * //         Name: "STRING_VALUE",
 * //         Value: "STRING_VALUE",
 * //       },
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListContactReferencesCommandInput - {@link ListContactReferencesCommandInput}
 * @returns {@link ListContactReferencesCommandOutput}
 * @see {@link ListContactReferencesCommandInput} for command's `input` shape.
 * @see {@link ListContactReferencesCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListContactReferencesCommand extends ListContactReferencesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListContactReferencesRequest;
            output: ListContactReferencesResponse;
        };
        sdk: {
            input: ListContactReferencesCommandInput;
            output: ListContactReferencesCommandOutput;
        };
    };
}
