import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListIntegrationAssociationsRequest, ListIntegrationAssociationsResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListIntegrationAssociationsCommand}.
 */
export interface ListIntegrationAssociationsCommandInput extends ListIntegrationAssociationsRequest {
}
/**
 * @public
 *
 * The output of {@link ListIntegrationAssociationsCommand}.
 */
export interface ListIntegrationAssociationsCommandOutput extends ListIntegrationAssociationsResponse, __MetadataBearer {
}
declare const ListIntegrationAssociationsCommand_base: {
    new (input: ListIntegrationAssociationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListIntegrationAssociationsCommandInput, ListIntegrationAssociationsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListIntegrationAssociationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListIntegrationAssociationsCommandInput, ListIntegrationAssociationsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Provides summary information about the Amazon Web Services resource associations for the
 *    specified Amazon Connect instance.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListIntegrationAssociationsCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListIntegrationAssociationsCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListIntegrationAssociationsRequest
 *   InstanceId: "STRING_VALUE", // required
 *   IntegrationType: "EVENT" || "VOICE_ID" || "PINPOINT_APP" || "WISDOM_ASSISTANT" || "WISDOM_KNOWLEDGE_BASE" || "WISDOM_QUICK_RESPONSES" || "Q_MESSAGE_TEMPLATES" || "CASES_DOMAIN" || "APPLICATION" || "FILE_SCANNER" || "SES_IDENTITY" || "ANALYTICS_CONNECTOR" || "CALL_TRANSFER_CONNECTOR" || "COGNITO_USER_POOL",
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 *   IntegrationArn: "STRING_VALUE",
 * };
 * const command = new ListIntegrationAssociationsCommand(input);
 * const response = await client.send(command);
 * // { // ListIntegrationAssociationsResponse
 * //   IntegrationAssociationSummaryList: [ // IntegrationAssociationSummaryList
 * //     { // IntegrationAssociationSummary
 * //       IntegrationAssociationId: "STRING_VALUE",
 * //       IntegrationAssociationArn: "STRING_VALUE",
 * //       InstanceId: "STRING_VALUE",
 * //       IntegrationType: "EVENT" || "VOICE_ID" || "PINPOINT_APP" || "WISDOM_ASSISTANT" || "WISDOM_KNOWLEDGE_BASE" || "WISDOM_QUICK_RESPONSES" || "Q_MESSAGE_TEMPLATES" || "CASES_DOMAIN" || "APPLICATION" || "FILE_SCANNER" || "SES_IDENTITY" || "ANALYTICS_CONNECTOR" || "CALL_TRANSFER_CONNECTOR" || "COGNITO_USER_POOL",
 * //       IntegrationArn: "STRING_VALUE",
 * //       SourceApplicationUrl: "STRING_VALUE",
 * //       SourceApplicationName: "STRING_VALUE",
 * //       SourceType: "SALESFORCE" || "ZENDESK" || "CASES",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListIntegrationAssociationsCommandInput - {@link ListIntegrationAssociationsCommandInput}
 * @returns {@link ListIntegrationAssociationsCommandOutput}
 * @see {@link ListIntegrationAssociationsCommandInput} for command's `input` shape.
 * @see {@link ListIntegrationAssociationsCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListIntegrationAssociationsCommand extends ListIntegrationAssociationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListIntegrationAssociationsRequest;
            output: ListIntegrationAssociationsResponse;
        };
        sdk: {
            input: ListIntegrationAssociationsCommandInput;
            output: ListIntegrationAssociationsCommandOutput;
        };
    };
}
