import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListPredefinedAttributesRequest, ListPredefinedAttributesResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListPredefinedAttributesCommand}.
 */
export interface ListPredefinedAttributesCommandInput extends ListPredefinedAttributesRequest {
}
/**
 * @public
 *
 * The output of {@link ListPredefinedAttributesCommand}.
 */
export interface ListPredefinedAttributesCommandOutput extends ListPredefinedAttributesResponse, __MetadataBearer {
}
declare const ListPredefinedAttributesCommand_base: {
    new (input: ListPredefinedAttributesCommandInput): import("@smithy/smithy-client").CommandImpl<ListPredefinedAttributesCommandInput, ListPredefinedAttributesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListPredefinedAttributesCommandInput): import("@smithy/smithy-client").CommandImpl<ListPredefinedAttributesCommandInput, ListPredefinedAttributesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists predefined attributes for the specified Amazon Connect instance. <i>Predefined
 *     attributes</i> are attributes in an Amazon Connect instance that can be used to route
 *    contacts to an agent or pools of agents within a queue. For more information, see <a href="https://docs.aws.amazon.com/connect/latest/adminguide/predefined-attributes.html">Create
 *     predefined attributes for routing contacts to agents</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListPredefinedAttributesCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListPredefinedAttributesCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListPredefinedAttributesRequest
 *   InstanceId: "STRING_VALUE", // required
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new ListPredefinedAttributesCommand(input);
 * const response = await client.send(command);
 * // { // ListPredefinedAttributesResponse
 * //   NextToken: "STRING_VALUE",
 * //   PredefinedAttributeSummaryList: [ // PredefinedAttributeSummaryList
 * //     { // PredefinedAttributeSummary
 * //       Name: "STRING_VALUE",
 * //       LastModifiedTime: new Date("TIMESTAMP"),
 * //       LastModifiedRegion: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListPredefinedAttributesCommandInput - {@link ListPredefinedAttributesCommandInput}
 * @returns {@link ListPredefinedAttributesCommandOutput}
 * @see {@link ListPredefinedAttributesCommandInput} for command's `input` shape.
 * @see {@link ListPredefinedAttributesCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListPredefinedAttributesCommand extends ListPredefinedAttributesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListPredefinedAttributesRequest;
            output: ListPredefinedAttributesResponse;
        };
        sdk: {
            input: ListPredefinedAttributesCommandInput;
            output: ListPredefinedAttributesCommandOutput;
        };
    };
}
