import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListRoutingProfileQueuesRequest, ListRoutingProfileQueuesResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListRoutingProfileQueuesCommand}.
 */
export interface ListRoutingProfileQueuesCommandInput extends ListRoutingProfileQueuesRequest {
}
/**
 * @public
 *
 * The output of {@link ListRoutingProfileQueuesCommand}.
 */
export interface ListRoutingProfileQueuesCommandOutput extends ListRoutingProfileQueuesResponse, __MetadataBearer {
}
declare const ListRoutingProfileQueuesCommand_base: {
    new (input: ListRoutingProfileQueuesCommandInput): import("@smithy/smithy-client").CommandImpl<ListRoutingProfileQueuesCommandInput, ListRoutingProfileQueuesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListRoutingProfileQueuesCommandInput): import("@smithy/smithy-client").CommandImpl<ListRoutingProfileQueuesCommandInput, ListRoutingProfileQueuesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists the queues associated with a routing profile.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListRoutingProfileQueuesCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListRoutingProfileQueuesCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListRoutingProfileQueuesRequest
 *   InstanceId: "STRING_VALUE", // required
 *   RoutingProfileId: "STRING_VALUE", // required
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new ListRoutingProfileQueuesCommand(input);
 * const response = await client.send(command);
 * // { // ListRoutingProfileQueuesResponse
 * //   NextToken: "STRING_VALUE",
 * //   RoutingProfileQueueConfigSummaryList: [ // RoutingProfileQueueConfigSummaryList
 * //     { // RoutingProfileQueueConfigSummary
 * //       QueueId: "STRING_VALUE", // required
 * //       QueueArn: "STRING_VALUE", // required
 * //       QueueName: "STRING_VALUE", // required
 * //       Priority: Number("int"), // required
 * //       Delay: Number("int"), // required
 * //       Channel: "VOICE" || "CHAT" || "TASK" || "EMAIL", // required
 * //     },
 * //   ],
 * //   LastModifiedTime: new Date("TIMESTAMP"),
 * //   LastModifiedRegion: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListRoutingProfileQueuesCommandInput - {@link ListRoutingProfileQueuesCommandInput}
 * @returns {@link ListRoutingProfileQueuesCommandOutput}
 * @see {@link ListRoutingProfileQueuesCommandInput} for command's `input` shape.
 * @see {@link ListRoutingProfileQueuesCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListRoutingProfileQueuesCommand extends ListRoutingProfileQueuesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListRoutingProfileQueuesRequest;
            output: ListRoutingProfileQueuesResponse;
        };
        sdk: {
            input: ListRoutingProfileQueuesCommandInput;
            output: ListRoutingProfileQueuesCommandOutput;
        };
    };
}
