import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListSecurityKeysRequest, ListSecurityKeysResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListSecurityKeysCommand}.
 */
export interface ListSecurityKeysCommandInput extends ListSecurityKeysRequest {
}
/**
 * @public
 *
 * The output of {@link ListSecurityKeysCommand}.
 */
export interface ListSecurityKeysCommandOutput extends ListSecurityKeysResponse, __MetadataBearer {
}
declare const ListSecurityKeysCommand_base: {
    new (input: ListSecurityKeysCommandInput): import("@smithy/smithy-client").CommandImpl<ListSecurityKeysCommandInput, ListSecurityKeysCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListSecurityKeysCommandInput): import("@smithy/smithy-client").CommandImpl<ListSecurityKeysCommandInput, ListSecurityKeysCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>This API is in preview release for Amazon Connect and is subject to change.</p>
 *          <p>Returns a paginated list of all security keys associated with the instance.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListSecurityKeysCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListSecurityKeysCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListSecurityKeysRequest
 *   InstanceId: "STRING_VALUE", // required
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new ListSecurityKeysCommand(input);
 * const response = await client.send(command);
 * // { // ListSecurityKeysResponse
 * //   SecurityKeys: [ // SecurityKeysList
 * //     { // SecurityKey
 * //       AssociationId: "STRING_VALUE",
 * //       Key: "STRING_VALUE",
 * //       CreationTime: new Date("TIMESTAMP"),
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListSecurityKeysCommandInput - {@link ListSecurityKeysCommandInput}
 * @returns {@link ListSecurityKeysCommandOutput}
 * @see {@link ListSecurityKeysCommandInput} for command's `input` shape.
 * @see {@link ListSecurityKeysCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListSecurityKeysCommand extends ListSecurityKeysCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListSecurityKeysRequest;
            output: ListSecurityKeysResponse;
        };
        sdk: {
            input: ListSecurityKeysCommandInput;
            output: ListSecurityKeysCommandOutput;
        };
    };
}
