import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListTrafficDistributionGroupUsersRequest, ListTrafficDistributionGroupUsersResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListTrafficDistributionGroupUsersCommand}.
 */
export interface ListTrafficDistributionGroupUsersCommandInput extends ListTrafficDistributionGroupUsersRequest {
}
/**
 * @public
 *
 * The output of {@link ListTrafficDistributionGroupUsersCommand}.
 */
export interface ListTrafficDistributionGroupUsersCommandOutput extends ListTrafficDistributionGroupUsersResponse, __MetadataBearer {
}
declare const ListTrafficDistributionGroupUsersCommand_base: {
    new (input: ListTrafficDistributionGroupUsersCommandInput): import("@smithy/smithy-client").CommandImpl<ListTrafficDistributionGroupUsersCommandInput, ListTrafficDistributionGroupUsersCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListTrafficDistributionGroupUsersCommandInput): import("@smithy/smithy-client").CommandImpl<ListTrafficDistributionGroupUsersCommandInput, ListTrafficDistributionGroupUsersCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists traffic distribution group users.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListTrafficDistributionGroupUsersCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListTrafficDistributionGroupUsersCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListTrafficDistributionGroupUsersRequest
 *   TrafficDistributionGroupId: "STRING_VALUE", // required
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 * };
 * const command = new ListTrafficDistributionGroupUsersCommand(input);
 * const response = await client.send(command);
 * // { // ListTrafficDistributionGroupUsersResponse
 * //   NextToken: "STRING_VALUE",
 * //   TrafficDistributionGroupUserSummaryList: [ // TrafficDistributionGroupUserSummaryList
 * //     { // TrafficDistributionGroupUserSummary
 * //       UserId: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListTrafficDistributionGroupUsersCommandInput - {@link ListTrafficDistributionGroupUsersCommandInput}
 * @returns {@link ListTrafficDistributionGroupUsersCommandOutput}
 * @see {@link ListTrafficDistributionGroupUsersCommandInput} for command's `input` shape.
 * @see {@link ListTrafficDistributionGroupUsersCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient permissions to perform this action.</p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListTrafficDistributionGroupUsersCommand extends ListTrafficDistributionGroupUsersCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListTrafficDistributionGroupUsersRequest;
            output: ListTrafficDistributionGroupUsersResponse;
        };
        sdk: {
            input: ListTrafficDistributionGroupUsersCommandInput;
            output: ListTrafficDistributionGroupUsersCommandOutput;
        };
    };
}
