import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { ListUseCasesRequest, ListUseCasesResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListUseCasesCommand}.
 */
export interface ListUseCasesCommandInput extends ListUseCasesRequest {
}
/**
 * @public
 *
 * The output of {@link ListUseCasesCommand}.
 */
export interface ListUseCasesCommandOutput extends ListUseCasesResponse, __MetadataBearer {
}
declare const ListUseCasesCommand_base: {
    new (input: ListUseCasesCommandInput): import("@smithy/smithy-client").CommandImpl<ListUseCasesCommandInput, ListUseCasesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListUseCasesCommandInput): import("@smithy/smithy-client").CommandImpl<ListUseCasesCommandInput, ListUseCasesCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists the use cases for the integration association. </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, ListUseCasesCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, ListUseCasesCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // ListUseCasesRequest
 *   InstanceId: "STRING_VALUE", // required
 *   IntegrationAssociationId: "STRING_VALUE", // required
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new ListUseCasesCommand(input);
 * const response = await client.send(command);
 * // { // ListUseCasesResponse
 * //   UseCaseSummaryList: [ // UseCaseSummaryList
 * //     { // UseCase
 * //       UseCaseId: "STRING_VALUE",
 * //       UseCaseArn: "STRING_VALUE",
 * //       UseCaseType: "RULES_EVALUATION" || "CONNECT_CAMPAIGNS",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListUseCasesCommandInput - {@link ListUseCasesCommandInput}
 * @returns {@link ListUseCasesCommandOutput}
 * @see {@link ListUseCasesCommandInput} for command's `input` shape.
 * @see {@link ListUseCasesCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class ListUseCasesCommand extends ListUseCasesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListUseCasesRequest;
            output: ListUseCasesResponse;
        };
        sdk: {
            input: ListUseCasesCommandInput;
            output: ListUseCasesCommandOutput;
        };
    };
}
