import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { PauseContactRequest, PauseContactResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link PauseContactCommand}.
 */
export interface PauseContactCommandInput extends PauseContactRequest {
}
/**
 * @public
 *
 * The output of {@link PauseContactCommand}.
 */
export interface PauseContactCommandOutput extends PauseContactResponse, __MetadataBearer {
}
declare const PauseContactCommand_base: {
    new (input: PauseContactCommandInput): import("@smithy/smithy-client").CommandImpl<PauseContactCommandInput, PauseContactCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: PauseContactCommandInput): import("@smithy/smithy-client").CommandImpl<PauseContactCommandInput, PauseContactCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Allows pausing an ongoing task contact.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, PauseContactCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, PauseContactCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // PauseContactRequest
 *   ContactId: "STRING_VALUE", // required
 *   InstanceId: "STRING_VALUE", // required
 *   ContactFlowId: "STRING_VALUE",
 * };
 * const command = new PauseContactCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param PauseContactCommandInput - {@link PauseContactCommandInput}
 * @returns {@link PauseContactCommandOutput}
 * @see {@link PauseContactCommandInput} for command's `input` shape.
 * @see {@link PauseContactCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient permissions to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Operation cannot be performed at this time as there is a conflict with another operation or
 *    contact state.</p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>The allowed limit for the resource has been exceeded.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class PauseContactCommand extends PauseContactCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: PauseContactRequest;
            output: {};
        };
        sdk: {
            input: PauseContactCommandInput;
            output: PauseContactCommandOutput;
        };
    };
}
