import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { SearchResourceTagsRequest, SearchResourceTagsResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link SearchResourceTagsCommand}.
 */
export interface SearchResourceTagsCommandInput extends SearchResourceTagsRequest {
}
/**
 * @public
 *
 * The output of {@link SearchResourceTagsCommand}.
 */
export interface SearchResourceTagsCommandOutput extends SearchResourceTagsResponse, __MetadataBearer {
}
declare const SearchResourceTagsCommand_base: {
    new (input: SearchResourceTagsCommandInput): import("@smithy/smithy-client").CommandImpl<SearchResourceTagsCommandInput, SearchResourceTagsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: SearchResourceTagsCommandInput): import("@smithy/smithy-client").CommandImpl<SearchResourceTagsCommandInput, SearchResourceTagsCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Searches tags used in an Amazon Connect instance using optional search criteria.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, SearchResourceTagsCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, SearchResourceTagsCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // SearchResourceTagsRequest
 *   InstanceId: "STRING_VALUE", // required
 *   ResourceTypes: [ // ResourceTypeList
 *     "STRING_VALUE",
 *   ],
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 *   SearchCriteria: { // ResourceTagsSearchCriteria
 *     TagSearchCondition: { // TagSearchCondition
 *       tagKey: "STRING_VALUE",
 *       tagValue: "STRING_VALUE",
 *       tagKeyComparisonType: "STARTS_WITH" || "CONTAINS" || "EXACT",
 *       tagValueComparisonType: "STARTS_WITH" || "CONTAINS" || "EXACT",
 *     },
 *   },
 * };
 * const command = new SearchResourceTagsCommand(input);
 * const response = await client.send(command);
 * // { // SearchResourceTagsResponse
 * //   Tags: [ // TagsList
 * //     { // TagSet
 * //       key: "STRING_VALUE",
 * //       value: "STRING_VALUE",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param SearchResourceTagsCommandInput - {@link SearchResourceTagsCommandInput}
 * @returns {@link SearchResourceTagsCommandOutput}
 * @see {@link SearchResourceTagsCommandInput} for command's `input` shape.
 * @see {@link SearchResourceTagsCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link MaximumResultReturnedException} (client fault)
 *  <p>Maximum number (1000) of tags have been returned with current request. Consider changing
 *    request parameters to get more tags.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class SearchResourceTagsCommand extends SearchResourceTagsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: SearchResourceTagsRequest;
            output: SearchResourceTagsResponse;
        };
        sdk: {
            input: SearchResourceTagsCommandInput;
            output: SearchResourceTagsCommandOutput;
        };
    };
}
