import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { StartOutboundEmailContactRequest, StartOutboundEmailContactResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link StartOutboundEmailContactCommand}.
 */
export interface StartOutboundEmailContactCommandInput extends StartOutboundEmailContactRequest {
}
/**
 * @public
 *
 * The output of {@link StartOutboundEmailContactCommand}.
 */
export interface StartOutboundEmailContactCommandOutput extends StartOutboundEmailContactResponse, __MetadataBearer {
}
declare const StartOutboundEmailContactCommand_base: {
    new (input: StartOutboundEmailContactCommandInput): import("@smithy/smithy-client").CommandImpl<StartOutboundEmailContactCommandInput, StartOutboundEmailContactCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: StartOutboundEmailContactCommandInput): import("@smithy/smithy-client").CommandImpl<StartOutboundEmailContactCommandInput, StartOutboundEmailContactCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Initiates a flow to send an agent reply or outbound email contact (created from the
 *    CreateContact API) to a customer.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, StartOutboundEmailContactCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, StartOutboundEmailContactCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // StartOutboundEmailContactRequest
 *   InstanceId: "STRING_VALUE", // required
 *   ContactId: "STRING_VALUE", // required
 *   FromEmailAddress: { // EmailAddressInfo
 *     EmailAddress: "STRING_VALUE", // required
 *     DisplayName: "STRING_VALUE",
 *   },
 *   DestinationEmailAddress: {
 *     EmailAddress: "STRING_VALUE", // required
 *     DisplayName: "STRING_VALUE",
 *   },
 *   AdditionalRecipients: { // OutboundAdditionalRecipients
 *     CcEmailAddresses: [ // EmailAddressRecipientList
 *       {
 *         EmailAddress: "STRING_VALUE", // required
 *         DisplayName: "STRING_VALUE",
 *       },
 *     ],
 *   },
 *   EmailMessage: { // OutboundEmailContent
 *     MessageSourceType: "TEMPLATE" || "RAW", // required
 *     TemplatedMessageConfig: { // TemplatedMessageConfig
 *       KnowledgeBaseId: "STRING_VALUE", // required
 *       MessageTemplateId: "STRING_VALUE", // required
 *       TemplateAttributes: { // TemplateAttributes
 *         CustomAttributes: { // Attributes
 *           "<keys>": "STRING_VALUE",
 *         },
 *         CustomerProfileAttributes: "STRING_VALUE",
 *       },
 *     },
 *     RawMessage: { // OutboundRawMessage
 *       Subject: "STRING_VALUE", // required
 *       Body: "STRING_VALUE", // required
 *       ContentType: "STRING_VALUE", // required
 *     },
 *   },
 *   ClientToken: "STRING_VALUE",
 * };
 * const command = new StartOutboundEmailContactCommand(input);
 * const response = await client.send(command);
 * // { // StartOutboundEmailContactResponse
 * //   ContactId: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param StartOutboundEmailContactCommandInput - {@link StartOutboundEmailContactCommandInput}
 * @returns {@link StartOutboundEmailContactCommandOutput}
 * @see {@link StartOutboundEmailContactCommandInput} for command's `input` shape.
 * @see {@link StartOutboundEmailContactCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient permissions to perform this action.</p>
 *
 * @throws {@link IdempotencyException} (client fault)
 *  <p>An entity with the same name already exists.</p>
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>The service quota has been exceeded.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class StartOutboundEmailContactCommand extends StartOutboundEmailContactCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: StartOutboundEmailContactRequest;
            output: StartOutboundEmailContactResponse;
        };
        sdk: {
            input: StartOutboundEmailContactCommandInput;
            output: StartOutboundEmailContactCommandOutput;
        };
    };
}
