import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { UpdatePredefinedAttributeRequest } from "../models/models_3";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdatePredefinedAttributeCommand}.
 */
export interface UpdatePredefinedAttributeCommandInput extends UpdatePredefinedAttributeRequest {
}
/**
 * @public
 *
 * The output of {@link UpdatePredefinedAttributeCommand}.
 */
export interface UpdatePredefinedAttributeCommandOutput extends __MetadataBearer {
}
declare const UpdatePredefinedAttributeCommand_base: {
    new (input: UpdatePredefinedAttributeCommandInput): import("@smithy/smithy-client").CommandImpl<UpdatePredefinedAttributeCommandInput, UpdatePredefinedAttributeCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: UpdatePredefinedAttributeCommandInput): import("@smithy/smithy-client").CommandImpl<UpdatePredefinedAttributeCommandInput, UpdatePredefinedAttributeCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates a predefined attribute for the specified Amazon Connect instance. <i>Predefined
 *     attributes</i> are attributes in an Amazon Connect instance that can be used to route
 *    contacts to an agent or pools of agents within a queue. For more information, see <a href="https://docs.aws.amazon.com/connect/latest/adminguide/predefined-attributes.html">Create
 *     predefined attributes for routing contacts to agents</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, UpdatePredefinedAttributeCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, UpdatePredefinedAttributeCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // UpdatePredefinedAttributeRequest
 *   InstanceId: "STRING_VALUE", // required
 *   Name: "STRING_VALUE", // required
 *   Values: { // PredefinedAttributeValues Union: only one key present
 *     StringList: [ // PredefinedAttributeStringValuesList
 *       "STRING_VALUE",
 *     ],
 *   },
 * };
 * const command = new UpdatePredefinedAttributeCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UpdatePredefinedAttributeCommandInput - {@link UpdatePredefinedAttributeCommandInput}
 * @returns {@link UpdatePredefinedAttributeCommandOutput}
 * @see {@link UpdatePredefinedAttributeCommandInput} for command's `input` shape.
 * @see {@link UpdatePredefinedAttributeCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class UpdatePredefinedAttributeCommand extends UpdatePredefinedAttributeCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UpdatePredefinedAttributeRequest;
            output: {};
        };
        sdk: {
            input: UpdatePredefinedAttributeCommandInput;
            output: UpdatePredefinedAttributeCommandOutput;
        };
    };
}
