import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { UpdatePromptRequest, UpdatePromptResponse } from "../models/models_3";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdatePromptCommand}.
 */
export interface UpdatePromptCommandInput extends UpdatePromptRequest {
}
/**
 * @public
 *
 * The output of {@link UpdatePromptCommand}.
 */
export interface UpdatePromptCommandOutput extends UpdatePromptResponse, __MetadataBearer {
}
declare const UpdatePromptCommand_base: {
    new (input: UpdatePromptCommandInput): import("@smithy/smithy-client").CommandImpl<UpdatePromptCommandInput, UpdatePromptCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: UpdatePromptCommandInput): import("@smithy/smithy-client").CommandImpl<UpdatePromptCommandInput, UpdatePromptCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates a prompt.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, UpdatePromptCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, UpdatePromptCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // UpdatePromptRequest
 *   InstanceId: "STRING_VALUE", // required
 *   PromptId: "STRING_VALUE", // required
 *   Name: "STRING_VALUE",
 *   Description: "STRING_VALUE",
 *   S3Uri: "STRING_VALUE",
 * };
 * const command = new UpdatePromptCommand(input);
 * const response = await client.send(command);
 * // { // UpdatePromptResponse
 * //   PromptARN: "STRING_VALUE",
 * //   PromptId: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param UpdatePromptCommandInput - {@link UpdatePromptCommandInput}
 * @returns {@link UpdatePromptCommandOutput}
 * @see {@link UpdatePromptCommandInput} for command's `input` shape.
 * @see {@link UpdatePromptCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class UpdatePromptCommand extends UpdatePromptCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UpdatePromptRequest;
            output: UpdatePromptResponse;
        };
        sdk: {
            input: UpdatePromptCommandInput;
            output: UpdatePromptCommandOutput;
        };
    };
}
