import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { UpdateUserHierarchyStructureRequest } from "../models/models_3";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdateUserHierarchyStructureCommand}.
 */
export interface UpdateUserHierarchyStructureCommandInput extends UpdateUserHierarchyStructureRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateUserHierarchyStructureCommand}.
 */
export interface UpdateUserHierarchyStructureCommandOutput extends __MetadataBearer {
}
declare const UpdateUserHierarchyStructureCommand_base: {
    new (input: UpdateUserHierarchyStructureCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateUserHierarchyStructureCommandInput, UpdateUserHierarchyStructureCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: UpdateUserHierarchyStructureCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateUserHierarchyStructureCommandInput, UpdateUserHierarchyStructureCommandOutput, ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates the user hierarchy structure: add, remove, and rename user hierarchy levels.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, UpdateUserHierarchyStructureCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, UpdateUserHierarchyStructureCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const input = { // UpdateUserHierarchyStructureRequest
 *   HierarchyStructure: { // HierarchyStructureUpdate
 *     LevelOne: { // HierarchyLevelUpdate
 *       Name: "STRING_VALUE", // required
 *     },
 *     LevelTwo: {
 *       Name: "STRING_VALUE", // required
 *     },
 *     LevelThree: {
 *       Name: "STRING_VALUE", // required
 *     },
 *     LevelFour: {
 *       Name: "STRING_VALUE", // required
 *     },
 *     LevelFive: {
 *       Name: "STRING_VALUE", // required
 *     },
 *   },
 *   InstanceId: "STRING_VALUE", // required
 * };
 * const command = new UpdateUserHierarchyStructureCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UpdateUserHierarchyStructureCommandInput - {@link UpdateUserHierarchyStructureCommandInput}
 * @returns {@link UpdateUserHierarchyStructureCommandOutput}
 * @see {@link UpdateUserHierarchyStructureCommandInput} for command's `input` shape.
 * @see {@link UpdateUserHierarchyStructureCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 * @throws {@link InternalServiceException} (server fault)
 *  <p>Request processing failed because of an error or failure with the service.</p>
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the specified parameters are not valid.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceInUseException} (client fault)
 *  <p>That resource is already in use. Please try another.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource was not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The throttling limit has been exceeded.</p>
 *
 * @throws {@link ConnectServiceException}
 * <p>Base exception class for all service exceptions from Connect service.</p>
 *
 *
 * @public
 */
export declare class UpdateUserHierarchyStructureCommand extends UpdateUserHierarchyStructureCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UpdateUserHierarchyStructureRequest;
            output: {};
        };
        sdk: {
            input: UpdateUserHierarchyStructureCommandInput;
            output: UpdateUserHierarchyStructureCommandOutput;
        };
    };
}
